<template>
  <el-dialog
    :title="!dataForm.id ? '新增' : '修改'"
    width="500px"
    :visible.sync="visible"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="100px"
      class="l-mes"
    >
      <el-form-item
        v-if="dataForm.id"
        label="标签身份码"
        prop="labelUniqueCode"
      >
        <el-input v-model="dataForm.labelUniqueCode" disabled />
      </el-form-item>
      <el-form-item label="标签类别描述" prop="labelTypeDesc">
        <el-select
          v-model="dataForm.labelTypeDesc"
          filterable
          clearable
          style="width: 100%"
        >
          <el-option
            v-for="item in labelTypeOptions"
            :key="item.id"
            :label="item.label"
            :value="item.value"
          />
        </el-select>
      </el-form-item>
      <el-form-item label="标签描述" prop="labelDesc">
        <el-input v-model="dataForm.labelDesc" />
      </el-form-item>
      <el-form-item label="标签尺寸" prop="labelSize">
        <el-input v-model="dataForm.labelSize" />
      </el-form-item>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
      >
        确定
      </el-button>
    </span>
  </el-dialog>
</template>
<script>
import { getObj, addObj, putObj } from '@/api/print/config'
import { remote } from '@/api/admin/dict'
const dataFormDefault = () => {
  return {
    id: null,
    labelUniqueCode: null,
    labelTypeDesc: null,
    labelDesc: null,
    labelSize: null
  }
}
export default {
  data() {
    return {
      visible: false,
      dataForm: dataFormDefault(),
      dataRule: {
        labelTypeDesc: [
          { required: true, message: '标签类别描述', trigger: 'blur' }
        ],
        labelDesc: [{ required: true, message: '标签描述', trigger: 'blur' }]
      },
      isSubmit: false,
      labelTypeOptions: []
    }
  },
  created() {
    remote('label_type').then((response) => {
      if (response.data.code === 0) {
        this.labelTypeOptions = response.data.data
      }
    })
  },
  methods: {
    init(id) {
      this.dataForm.id = id || 0
      this.visible = true
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getObj(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
          })
        }
      })
    },
    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (this.dataForm.id) {
            putObj(this.dataForm).then((data) => {
              this.$message.success('修改成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          } else {
            addObj(this.dataForm).then((data) => {
              this.$message.success('添加成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          }
        } else {
          this.isSubmit = false
        }
      })
    }
  }
}
</script>
